### This display all variables

(see src/hatch_ci/tools.py:get_data)

- **ctx.version**  0.1.4b59
- **ctx.current**  0.1.4
- **ctx.ref**      refs/heads/beta/0.1.4
- **ctx.branch**   beta/0.1.4
- **ctx.sha**      7dbfdf33d3c501be74c6908cd1df70e19c824648
- **ctx.build**    59
- **ctx.runid**    8470503945
- **ctx.workflow** beta